@@ -29,11 +29,7 @@ has '_last_language'       => ( is => 'rw', isa => 'Str', builder => '_build_las
 Readonly my %TAG_DESCRIPTIONS => (
     CANNOT_CONTINUE => sub {
         __x    # SYSTEM:CANNOT_CONTINUE
-          "Not enough data about {zone} was found to be able to run tests.", @_;
-    },
-    PROFILE_FILE => sub {
-        __x    # SYSTEM:PROFILE_FILE
-          "Profile was read from {name}.", @_;
+          "Not enough data about {domain} was found to be able to run tests.", @_;
     },
     DEPENDENCY_VERSION => sub {
         __x    # SYSTEM:DEPENDENCY_VERSION
@@ -49,7 +45,7 @@ Readonly my %TAG_DESCRIPTIONS => (
     },
     LOOKUP_ERROR => sub {
         __x    # SYSTEM:LOOKUP_ERROR
-          "DNS query to {ns} for {name}/{type}/{class} failed with error: {message}", @_;
+          "DNS query to {ns} for {domain}/{type}/{class} failed with error: {message}", @_;
     },
     MODULE_ERROR => sub {
         __x    # SYSTEM:MODULE_ERROR
@@ -69,19 +65,19 @@ Readonly my %TAG_DESCRIPTIONS => (
     },
     UNKNOWN_METHOD => sub {
         __x    # SYSTEM:UNKNOWN_METHOD
-          "Request to run unknown method {method} in module {module}.", @_;
+          "Request to run unknown method {testcase} in module {module}.", @_;
     },
     UNKNOWN_MODULE => sub {
         __x    # SYSTEM:UNKNOWN_MODULE
-          "Request to run {method} in unknown module {module}. Known modules: {known}.", @_;
+          "Request to run {testcase} in unknown module {module}. Known modules: {module_list}.", @_;
     },
     SKIP_IPV4_DISABLED => sub {
         __x    # SYSTEM:SKIP_IPV4_DISABLED
-          "IPv4 is disabled, not sending query to {ns_list}.", @_;
+          "IPv4 is disabled, not sending \"{rrtype}\" query to {ns}.", @_;
     },
     SKIP_IPV6_DISABLED => sub {
         __x    # SYSTEM:SKIP_IPV6_DISABLED
-          "IPv6 is disabled, not sending query to {ns_list}.", @_;
+          "IPv6 is disabled, not sending \"{rrtype}\" query to {ns}.", @_;
     },
     FAKE_DELEGATION => sub {
         __x    # SYSTEM:FAKE_DELEGATION
@@ -238,6 +234,17 @@ sub translate_tag {
     return $self->_translate_tag( $entry->module, $entry->tag, $entry->printable_args ) // $entry->string;
 }
 
+
+sub test_case_description {
+    my ( $self, $test_name ) = @_;
+
+    $test_name = uc $test_name;
+    my $module = $test_name;
+    $module =~ s/\d+$//;
+
+    return $self->_translate_tag( $module, $test_name, {} ) // $test_name;
+}
+
 sub _translate_tag {
     my ( $self, $module, $tag, $args ) = @_;
 
@@ -266,7 +273,7 @@ Zonemaster::Engine::Translator - translation support for Zonemaster
 
 =head1 SYNOPSIS
 
-    Zonemaster::Engine::Translator->initialize({ locale => 'sv_SE.UTF-8' });
+    Zonemaster::Engine::Translator->initialize( { locale => 'sv_SE.UTF-8' } );
 
     my $trans = Zonemaster::Engine::Translator->instance;
     say $trans->to_string($entry);
@@ -319,7 +326,7 @@ end-users.
 
 Provide initial values for the single instance of this class.
 
-    Zonemaster::Engine::Translator->initialize( locale => 'sv_SE.UTF-8' );
+    Zonemaster::Engine::Translator->initialize( { locale => 'sv_SE.UTF-8' } );
 
 This method must be called at most once and before the first call to instance().
 
@@ -352,10 +359,14 @@ setlocale( LC_MESSAGES, "" ).
 Takes a L<Zonemaster::Engine::Logger::Entry> object as its argument and returns a translated string with the timestamp, level, message and arguments in the
 entry.
 
-=item translate_tag
+=item translate_tag($entry)
 
 Takes a L<Zonemaster::Engine::Logger::Entry> object as its argument and returns a translation of its tag and arguments.
 
+=item test_case_description($testcase)
+
+Takes a string (test case ID) and returns the translated test case description.
+
 =item BUILD
 
 Internal method that's only mentioned here to placate L<Pod::Coverage>.
